<?php

namespace Drupal\search_api_decoupled_ui\Plugin\search_ui_element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\search_api_decoupled_ui\ConfigurableSearchUiElementBase;

/**
 * Provides a search UI element for active filters.
 *
 * @SearchUiElement(
 *   id = "active_filters",
 *   label = @Translation("Active filters"),
 *   description = @Translation("Displays the active filters for the search."),
 * )
 */
class ActiveFilters extends ConfigurableSearchUiElementBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'show_reset_link' => TRUE,
      'reset_text' => 'Clear all',
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['show_reset_link'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Include reset button'),
      '#default_value' => !empty($this->configuration['show_reset_link']),
    ];
    $form['reset_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Display label'),
      '#default_value' => $this->configuration['reset_text'],
      '#states' => [
        'visible' => [
          ':input[name="settings[show_reset_link]"]' => ['checked' => TRUE],
        ],
        'required' => [
          ':input[name="settings[show_reset_link]"]' => ['checked' => TRUE],
        ],
      ],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['reset_text'] = $form_state->getValue('reset_text');
    $this->configuration['show_reset_link'] = (bool) $form_state->getValue('show_reset_link');
  }

  /**
   * {@inheritdoc}
   */
  public function getSummary() {
    return [
      '#markup' => $this->t('Reset button label: @label.', ['@label' => $this->configuration['reset_text']]),
    ];
  }

}
